# Copyright (c) 2021-present, Hakan Özler
# All rights reserved.
#
# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

from .Pelikan import Pelikan
from .Pelikan import main



import unittest

import nbformat
from nbconvert import NotebookExporter

from pelikan import Pelikan


class TestPelikanCases(unittest.TestCase):

    def test_remove_comments(self):
        path = 'data/'
        notebook = path + 'notebook-comments.ipynb'
        new_notebook_name = 'notebook-without-comments'
        file_extension = '.ipynb'
        comment_free_notebooks = path + new_notebook_name + file_extension

        pelikan = Pelikan(notebook, new_notebook_name)
        source_actual, resources_actual = pelikan._convert_comment()

        with open(comment_free_notebooks) as fh:
            nb_comment_free = nbformat.reads(fh.read(), nbformat.NO_CONVERT)

        exporter = NotebookExporter()
        source_expected, resources_expected = exporter.from_notebook_node(nb_comment_free)

        self.assertEqual(source_actual, source_expected)


if __name__ == "__main__":
    unittest.main()



import argparse
import re
import sys
from pathlib import PosixPath

import nbformat
from nbconvert import NotebookExporter
from nbconvert.preprocessors import Preprocessor
from nbconvert.writers import FilesWriter
from traitlets.config import Config


class CommentRemovalSubCell(Preprocessor):

    def preprocess_cell(self, cell, resources, index):
        if cell.cell_type == 'code':
            cell.source = re.sub('(#).+', self._comment_repl, cell.source, flags=re.IGNORECASE)
        return cell, resources

    @staticmethod
    def _comment_repl(match_obj):
        if match_obj.group(0) == '#':
            return ''


class Pelikan:

    def __init__(self, notebook_path=None, notebook_name=None):
        assert notebook_path is not None
        assert notebook_name is not None

        self.notebook_name = notebook_name
        self.notebook_path = notebook_path

    def _convert_comment(self):
        with open(self.notebook_path) as fh:
            nb = nbformat.reads(fh.read(), nbformat.NO_CONVERT)

        c = Config()
        c.NotebookExporter.preprocessors = [CommentRemovalSubCell]
        exporter = NotebookExporter(config=c)
        return exporter.from_notebook_node(nb)

    def generate_notebook(self, destination_path=None) -> PosixPath:
        source, resources = self._convert_comment()

        fw = FilesWriter()
        if destination_path:
            fw.build_directory = destination_path
        return fw.write(source, resources, notebook_name=self.notebook_name)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--notebook",
        "-n",
        required=True,
        help="The notebook file we want to remove comments from")
    parser.add_argument(
        "--output",
        "-o",
        required=True,
        help="The name of the newly created comment-free notebook.")

    args = parser.parse_args(sys.argv[1:])
    pelikan = Pelikan(args.notebook, args.output)
    pelikan.generate_notebook()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pelikan",
    version="0.0.5",
    author="Hakan Ozler",
    author_email="ozler.hakan@gmail.com",
    description="a jupyter notebook tool to make notebooks comment-free",
    long_description=long_description,
    long_description_content_type="text/plain; charset=UTF-8",
    url="https://github.com/ozlerhakan/palikan",
    project_urls={
        "Bug Tracker": "https://github.com/ozlerhakan/pelikan/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    packages=setuptools.find_packages(),
    python_requires=">=3.7",
    keywords=["python", 'jupyter', 'notebooks'],
    install_requires=[
        'nbconvert>= 6.2.0',
        'nbformat>=5.1.3'
    ],
    entry_points={
        "console_scripts": [
            "pelikan=pelikan.Pelikan:main"
        ],
    }
)
